==> allure-report-data-1.4.7-sources.jar: ru/yandex/qatools/allure/data/converters/DefaultTestCaseConverter.java <==
package ru.yandex.qatools.allure.data.converters;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class DefaultTestCaseConverter
  extends java.lang.Object  implements
    ru.yandex.qatools.allure.data.converters.TestCaseConverter,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getSuiteUids() { return null;}
public  void setSuiteUids(java.lang.Object value) { }
@java.lang.Override() public  ru.yandex.qatools.allure.data.AllureTestCase convert(ru.yandex.qatools.allure.model.TestCaseResult result) { return (ru.yandex.qatools.allure.data.AllureTestCase)null;}
public class TestCaseResultProcessor
  extends java.lang.Object  implements
    org.modelmapper.Converter<ru.yandex.qatools.allure.model.TestCaseResult, ru.yandex.qatools.allure.data.AllureTestCase>,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
@java.lang.Override() public  ru.yandex.qatools.allure.data.AllureTestCase convert(org.modelmapper.spi.MappingContext<ru.yandex.qatools.allure.model.TestCaseResult, ru.yandex.qatools.allure.data.AllureTestCase> context) { return (ru.yandex.qatools.allure.data.AllureTestCase)null;}
}
public class StepProcessor
  extends java.lang.Object  implements
    org.modelmapper.Converter<ru.yandex.qatools.allure.model.Step, ru.yandex.qatools.allure.data.AllureStep>,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
@java.lang.Override() public  ru.yandex.qatools.allure.data.AllureStep convert(org.modelmapper.spi.MappingContext<ru.yandex.qatools.allure.model.Step, ru.yandex.qatools.allure.data.AllureStep> context) { return (ru.yandex.qatools.allure.data.AllureStep)null;}
}
public class AttachmentProcessor
  extends java.lang.Object  implements
    org.modelmapper.Converter<ru.yandex.qatools.allure.model.Attachment, ru.yandex.qatools.allure.data.AllureAttachment>,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
@java.lang.Override() public  ru.yandex.qatools.allure.data.AllureAttachment convert(org.modelmapper.spi.MappingContext<ru.yandex.qatools.allure.model.Attachment, ru.yandex.qatools.allure.data.AllureAttachment> context) { return (ru.yandex.qatools.allure.data.AllureAttachment)null;}
}
}

==> allure-report-data-1.4.10-sources.jar: ru/yandex/qatools/allure/data/converters/DefaultTestCaseConverter.java <==
package ru.yandex.qatools.allure.data.converters;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class DefaultTestCaseConverter
  extends java.lang.Object  implements
    ru.yandex.qatools.allure.data.converters.TestCaseConverter,    groovy.lang.GroovyObject {
public static final java.lang.String UNKNOWN_STEP_NAME = "UnknownStepName";
public static final java.lang.String UNKNOWN_TEST_SUITE = "UnknownTestSuite";
public static final java.lang.String UNKNOWN_TEST_CASE = "UnknownTestCase";
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getSuiteUids() { return null;}
public  void setSuiteUids(java.lang.Object value) { }
@java.lang.Override() public  ru.yandex.qatools.allure.data.AllureTestCase convert(ru.yandex.qatools.allure.model.TestCaseResult result) { return (ru.yandex.qatools.allure.data.AllureTestCase)null;}
public class TestCaseResultProcessor
  extends java.lang.Object  implements
    org.modelmapper.Converter<ru.yandex.qatools.allure.model.TestCaseResult, ru.yandex.qatools.allure.data.AllureTestCase>,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
@java.lang.Override() public  ru.yandex.qatools.allure.data.AllureTestCase convert(org.modelmapper.spi.MappingContext<ru.yandex.qatools.allure.model.TestCaseResult, ru.yandex.qatools.allure.data.AllureTestCase> context) { return (ru.yandex.qatools.allure.data.AllureTestCase)null;}
}
public class StepProcessor
  extends java.lang.Object  implements
    org.modelmapper.Converter<ru.yandex.qatools.allure.model.Step, ru.yandex.qatools.allure.data.AllureStep>,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
@java.lang.Override() public  ru.yandex.qatools.allure.data.AllureStep convert(org.modelmapper.spi.MappingContext<ru.yandex.qatools.allure.model.Step, ru.yandex.qatools.allure.data.AllureStep> context) { return (ru.yandex.qatools.allure.data.AllureStep)null;}
}
public class AttachmentProcessor
  extends java.lang.Object  implements
    org.modelmapper.Converter<ru.yandex.qatools.allure.model.Attachment, ru.yandex.qatools.allure.data.AllureAttachment>,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
@java.lang.Override() public  ru.yandex.qatools.allure.data.AllureAttachment convert(org.modelmapper.spi.MappingContext<ru.yandex.qatools.allure.model.Attachment, ru.yandex.qatools.allure.data.AllureAttachment> context) { return (ru.yandex.qatools.allure.data.AllureAttachment)null;}
}
}
